//
// FileName: OpaqueExample.cc
//
// Programmer: David Sowsy
//
// Purpose: To implement an example application that uses
//			opaque pop-up menus and pulldown menus. 
// 
// Notes: 
//
// Legal: OpaqueMenu Implementation © 1999 David Sowsy. 
// 
//        You can use this code free of charge, in any way, shape, 
//		  or form (commericially or non-commercially), provided you include 
//		  the following string in your program 'About' Requester and
//		  in your documentation: 		  
//			
//		  "OpaqueMenu Implementation ©1999 David Sowsy." 
// 
//        This code carries no warranties or guarantees of any kind. Use at your own risk.

#include <Be.h> 
#include "OpaquePopUpMenu.h"
#include "OpaqueMenuItem.h"
#include "OpaqueMenu.h"

// Put these somewhere more convenient in your application code. 
OpaquePopUpMenu * Pop; 
OpaqueMenuItem  * Example, * ExampleA, * ExampleB, * ExampleC, * ExampleD;
OpaqueMenu 		* menu,	   * menuA;
BMenuBar	    * mb;

BRect window_bounds(100,100,400,300);
BRect view_bounds(0,0,320,200); 

enum { NONE = 0, PREFERENCES,SOME }; 

class sApp : public BApplication
{
 public: 
		 sApp(void); 
		 virtual bool QuitRequested(); 
};
class sWindow : public BWindow
{
 public: 
		 sWindow(BRect frame, const char *name);
 		 virtual bool QuitRequested(); 

};

class sView : public BView
{
 public: 
		 sView(BRect frame, const char *name);
		 virtual void AttachedToWindow(void); 
		 virtual void MouseDown(BPoint point);
		 virtual void Pulse(void);    
};


// App subclassing. 
sApp :: sApp(void) : BApplication("application/x-vnd.Simply3D")
{ 
 BAlert * about = new BAlert("OpaquePopUpMenu\n",
		                     "OpaquePopUpMenu\n\n"
          			         "Example program showing an opaque/transparent a pop-up menu.\n"
                    		 "©1999 David Sowsy.\n"
                             "All Rights Reserved.", 
 							 "Nice to know.");  							  
 about->Go(); 
 
 sWindow * win = new sWindow(window_bounds, "Opaque menus example program");
 sView * aView = new sView(view_bounds, "view");
 
 win->AddChild(aView);
 win->Show(); 
}

// Window subclassing.
sWindow :: sWindow(BRect frame, const char *name) : BWindow(frame, name, B_TITLED_WINDOW,B_WILL_DRAW | B_PULSE_NEEDED)
{
 mb = new BMenuBar(BRect(0,0,frame.right,15), "File menu", B_FOLLOW_LEFT_RIGHT | B_FOLLOW_TOP, 
        					  B_ITEMS_IN_ROW, true);
     					  
 menu = new OpaqueMenu("Small menu",B_ITEMS_IN_COLUMN);
 menuA = new OpaqueMenu("Bigger Menu",B_ITEMS_IN_COLUMN);
 
 // Insert more menu items here. 

  menu->AddItem(new OpaqueMenuItem("About", new BMessage(NONE)));
  menuA->AddItem(new OpaqueMenuItem("Superstition", new BMessage(NONE), 'S', B_COMMAND_KEY));
  menuA->AddItem(new OpaqueMenuItem("Fear", new BMessage(NONE) , 'F', B_COMMAND_KEY));
  menuA->AddItem(new OpaqueMenuItem("Jealousy", new BMessage(NONE), 'J', B_COMMAND_KEY));
  menuA->AddItem(new OpaqueMenuItem("Eradicate Apple...", new BMessage(NONE),'E',B_COMMAND_KEY));
   
  menu->SetRadioMode(true); 
  menuA->SetRadioMode(true); 
 
  menuA->SetDrawingMode(B_OP_BLEND);
  menuA->SetViewColor(B_TRANSPARENT_COLOR); 
 
  menu->SetDrawingMode(B_OP_BLEND);
  menu->SetViewColor(B_TRANSPARENT_COLOR); 
   
  mb->AddItem(menu);
  mb->AddItem(menuA);
 
  AddChild(mb); 	 
  mb->AttachedToWindow(); 
  mb->SetTargetForItems(this); 
}

bool sWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return(true);
}

// View subclassing. 
sView :: sView(BRect frame, const char * name): BView(frame, name, B_FOLLOW_ALL, B_WILL_DRAW | B_PULSE_NEEDED)
{ 
 rgb_color maroon =  { 100,0, 0};
 SetViewColor(maroon); 
 
}

void sView :: Pulse(void)
{
 // Make sure we always get our transparent menus.
  Pop->SetDrawingMode(B_OP_BLEND);
  Pop->SetViewColor(B_TRANSPARENT_COLOR);

}

void sView :: AttachedToWindow(void)
{
 // Here's our entry point to set up and use the transparent popup.
 Pop = new OpaquePopUpMenu("TransMenuBar",true,true, B_ITEMS_IN_COLUMN);
   Example = new OpaqueMenuItem("Example item on the popup menu", new BMessage(NONE)); 
    ExampleA = new OpaqueMenuItem("Example item on the popup menu A ", new BMessage(NONE)); 
     ExampleB = new OpaqueMenuItem("Example item on the popup menu B", new BMessage(NONE)); 
      ExampleB= new OpaqueMenuItem("Example item on the popup menu C", new BMessage(NONE));  
       ExampleC = new OpaqueMenuItem("Example item on the popup menu D", new BMessage(NONE)); 
        ExampleD = new OpaqueMenuItem("Example item on the popup menu E", new BMessage(NONE)); 

 // Insert more menu items here. 
 Pop->AddItem(Example);
  Pop->AddItem(ExampleA);
   Pop->AddItem(ExampleB);
    Pop->AddItem(ExampleC);
     Pop->AddItem(ExampleD);
	   Pop->SetTargetForItems(this);
  
 		Pop->SetRadioMode(TRUE); 
 		Pop->AttachedToWindow();   
}

void sView :: MouseDown(BPoint point)
{
 BMenuItem * selected; 
 ConvertToScreen(&point); 
 BRect bounds = Pop->Bounds();
  		
  selected = Pop->Go(point, true, false, BRect(0,0,point.x + bounds.right, 
	 	            point.y + bounds.bottom));
  if(selected)
  {
   Window()->PostMessage(selected->Message() );   
  }			
}

bool sApp :: QuitRequested()
{
 be_app->PostMessage(B_QUIT_REQUESTED); 
 return(true);
}

void main(int argc, char *argv[])
{ 
 sApp OpaqueExample;
 OpaqueExample.Run();
}